Data Model To YAML
dm_to_yaml.RdConvert data model to YAML configuration file.
Details
The input data model should have its version = "0.8.0" otherwise an error
will be raised. Use dm_migrate() first if needed.
dm_to_yaml.RdConvert data model to YAML configuration file.
The input data model should have its version = "0.8.0" otherwise an error
will be raised. Use dm_migrate() first if needed.