Skip to contents

Builds the create or update item form.

Usage

form(attributes, items = NULL)

Arguments

attributes

a data.frame of the attributes (see details).

items

an optional data.frame of the items (see details).

Value

A list of HTML tags.

Details

attributes is expected to be the output of the default() or as_default() function. The data.frame should have the following columns: "name", "type", "default", "values".

items are required only when the attribute values defined in the data.model should be evaluated with data masking support.

Examples

if (FALSE) { # \dontrun{
form(attributes = data.frame(name = "total", type = "numeric"))
} # }