Sort Items
adjust.RdSort Items
Usage
adjust(items, config, item = get_context())Details
The sorting order is given by the sort entry in the config list.
When item is set in the parent frame, then the attribute can be skipped
in the function call.