Check Integrity
check.RdWrapper function to either check the YAML config or items integrity.
Details
The function is smart enough to detect what is passed to ....
To check the items, it is necessary to also pass the corresponding
id in the config (see examples).
Examples
if (FALSE) { # \dontrun{
# check config (list)
config <- design(project = "test")
check(config)
# check items (data.frame)
check(items, config, id = "foo")
} # }