Input Values
extract.RdExtract the list of values from the input.
Details
The output list will contain as many entries as the colClasses named vector.
In case some names have no corresponding item in the input parameter, they
will get NULL as value in the output list.
Examples
if (FALSE) { # \dontrun{
values <- extract(input, colClasses = c("date" = "Date", "text" = "character"))
} # }