Item Form
form.RdBuilds the create or update item form.
Details
attributes is expected to be the output of the default() or as_default() function.
The data.frame should have the following columns:
"name", "type", "default", "values".
items are required only when the attribute values defined in the data.model
should be evaluated with data masking support.
Examples
if (FALSE) { # \dontrun{
form(attributes = data.frame(name = "total", type = "numeric"))
} # }