Display Behavior Grammar
hide.RdA set of verbs to manipulate the display of an attribute.
Usage
hide(config, item = get_context(), ...)
display(config, item = get_context(), ...)
hidden(config, item = get_context())
displayed(config, item = get_context())Details
hide() and display() are setter functions to tune attribute's behavior.
hidden() and displayed() are getter functions to quickly access the attributes
to hide or display in the item table.
When item is set in the parent frame, then the attribute can be skipped
in the function call.
Examples
if (FALSE) { # \dontrun{
# hide attribute
config <- design(project = "test",
item = "foo") |>
extend(item = "foo", attribute = c(name = "date", type = "Date")) |>
hide(item = "foo", "date")
# allow skipping argument in following calls
item <- "foo"
# hidden attributes
config |> hidden()
# display attribute
config |> display("date")
# displayed attributes
config |> displayed()
} # }