Insert Item(s)
insert.RdInsert Item(s)
Details
The function is mostly a wrapper around dplyr::bind_rows() function.
It does check for potential duplicates among the 'id' column. If so, the operation will be aborted as there is no way to know how to fix the duplicated id(s).