Sort Items Grammar
organize.RdSet or get sorting order.
Usage
organize(config, item = get_context(), sort)
organized(config, item = get_context())Details
The organize function accepts a character string for sort because it is
primarily intended to deal with the Admin Console (which returns
a character string from the user input).
Setting sort = NULL will reset the item sorting!
Ranking depends on the position of the attribute. Wrap attribute name by "desc()" to set descending order.
When item is set in the parent frame, then the attribute can be skipped
in the function call.