Prepare Values
prepare.RdTurn trigger values into tabular data.
Usage
prepare(values, config, update = FALSE, item = get_context())Details
values is a named list. The names are used to check the corresponding values
vs the data.model (class, default values if the provided ones are not valid).
The elements in the list must have either length one or same length as the id element.
When an element has length one but the id has several values, all items corresponding
to these ids will be updated with same value. To do so, values will be turned into
a data.frame using as.data.frame ; for this reason, it's strongly advised to wrap
the call into tryCatch() as this may fail.
When item is set in the parent frame, then the attribute can be skipped
in the function call.