Trigger Event
trigger_event.RdHelper function to create events to be passed to kitems module server
with the trigger argument.
Details
The function also adds an event id to make it unique (otherwise sending two times the same request would fail).
For more details see this vignette:
vignette("workflows", package = "kitems")
Examples
if (FALSE) { # \dontrun{
# create dialog event
trigger_event()
# delete item event (without dialog)
trigger_event(workflow = "delete", type = "task", values = list(id = 1234))
} # }